@@ -95,11 +95,11 @@ def new_key_req(key, cert_path, server_host_name, private_key_passwd=None,
         passphrase_callback
 
     rsa = generateRSAKey()
-    rsa.save_key(key + '_pub', cipher=None, callback=lambda *unused: None)
+    rsa.save_key(key + '_pub', cipher=None, callback=lambda *unused: "")
 
     pkey = makePKey(rsa)
     if not passphrase_callback(private_key_passwd):
-        pkey.save_key(key, cipher=None, callback=lambda *unused: None)
+        pkey.save_key(key, cipher=None, callback=lambda *unused: "")
     else:
         pkey.save_key(key, callback=lambda *unused: str(private_key_passwd))
 
